#
# PySNMP MIB module ENTITY-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ENTITY-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:11:42 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, ValueRangeConstraint, ValueSizeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "ValueRangeConstraint", "ValueSizeConstraint", "SingleValueConstraint")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( Counter32, mib_2, Integer32, NotificationType, ObjectIdentity, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, iso, MibIdentifier, Counter64, TimeTicks, IpAddress, ModuleIdentity, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "mib-2", "Integer32", "NotificationType", "ObjectIdentity", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "iso", "MibIdentifier", "Counter64", "TimeTicks", "IpAddress", "ModuleIdentity", "Bits")
( TDomain, DateAndTime, TAddress, AutonomousType, RowPointer, TimeStamp, DisplayString, TextualConvention, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "TDomain", "DateAndTime", "TAddress", "AutonomousType", "RowPointer", "TimeStamp", "DisplayString", "TextualConvention", "TruthValue")
entityMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 47)).setRevisions(("2005-08-10 00:00", "1999-12-07 00:00", "1996-10-31 00:00",))
if mibBuilder.loadTexts: entityMIB.setLastUpdated('200508100000Z')
if mibBuilder.loadTexts: entityMIB.setOrganization('IETF ENTMIB Working Group')
if mibBuilder.loadTexts: entityMIB.setContactInfo('        WG E-mail: entmib@ietf.org\n                     Mailing list subscription info:\n                       http://www.ietf.org/mailman/listinfo/entmib\n\n                     Andy Bierman\n                     ietf@andybierman.com\n\n                     Keith McCloghrie\n                     Cisco Systems Inc.\n                     170 West Tasman Drive\n                     San Jose, CA 95134\n\n\n                     +1 408-526-5260\n                     kzm@cisco.com')
if mibBuilder.loadTexts: entityMIB.setDescription('The MIB module for representing multiple logical\n            entities supported by a single SNMP agent.\n\n            Copyright (C) The Internet Society (2005).  This\n            version of this MIB module is part of RFC 4133; see\n            the RFC itself for full legal notices.')
entityMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 1))
entityPhysical = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 1, 1))
entityLogical = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 1, 2))
entityMapping = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 1, 3))
entityGeneral = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 1, 4))
class PhysicalIndex(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,2147483647)

class PhysicalIndexOrZero(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class PhysicalClass(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("chassis", 3), ("backplane", 4), ("container", 5), ("powerSupply", 6), ("fan", 7), ("sensor", 8), ("module", 9), ("port", 10), ("stack", 11), ("cpu", 12),)

class SnmpEngineIdOrNone(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,32)

entPhysicalTable = MibTable((1, 3, 6, 1, 2, 1, 47, 1, 1, 1), )
if mibBuilder.loadTexts: entPhysicalTable.setDescription("This table contains one row per physical entity.  There is\n            always at least one row for an 'overall' physical entity.")
entPhysicalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1), ).setIndexNames((0, "ENTITY-MIB", "entPhysicalIndex"))
if mibBuilder.loadTexts: entPhysicalEntry.setDescription('Information about a particular physical entity.\n\n            Each entry provides objects (entPhysicalDescr,\n            entPhysicalVendorType, and entPhysicalClass) to help an NMS\n            identify and characterize the entry, and objects\n            (entPhysicalContainedIn and entPhysicalParentRelPos) to help\n            an NMS relate the particular entry to other entries in this\n            table.')
entPhysicalIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 1), PhysicalIndex())
if mibBuilder.loadTexts: entPhysicalIndex.setDescription('The index for this entry.')
entPhysicalDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalDescr.setDescription("A textual description of physical entity.  This object\n            should contain a string that identifies the manufacturer's\n            name for the physical entity, and should be set to a\n            distinct value for each version or model of the physical\n            entity.")
entPhysicalVendorType = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 3), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalVendorType.setDescription("An indication of the vendor-specific hardware type of the\n            physical entity.  Note that this is different from the\n            definition of MIB-II's sysObjectID.\n\n            An agent should set this object to an enterprise-specific\n            registration identifier value indicating the specific\n            equipment type in detail.  The associated instance of\n            entPhysicalClass is used to indicate the general type of\n            hardware device.\n\n            If no vendor-specific registration identifier exists for\n            this physical entity, or the value is unknown by this agent,\n            then the value { 0 0 } is returned.")
entPhysicalContainedIn = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 4), PhysicalIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalContainedIn.setDescription("The value of entPhysicalIndex for the physical entity which\n            'contains' this physical entity.  A value of zero indicates\n            this physical entity is not contained in any other physical\n            entity.  Note that the set of 'containment' relationships\n            define a strict hierarchy; that is, recursion is not\n            allowed.\n\n            In the event that a physical entity is contained by more\n            than one physical entity (e.g., double-wide modules), this\n            object should identify the containing entity with the lowest\n            value of entPhysicalIndex.")
entPhysicalClass = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 5), PhysicalClass()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalClass.setDescription("An indication of the general hardware type of the physical\n            entity.\n\n            An agent should set this object to the standard enumeration\n            value that most accurately indicates the general class of\n            the physical entity, or the primary class if there is more\n            than one entity.\n\n            If no appropriate standard registration identifier exists\n            for this physical entity, then the value 'other(1)' is\n            returned.  If the value is unknown by this agent, then the\n            value 'unknown(2)' is returned.")
entPhysicalParentRelPos = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalParentRelPos.setDescription("An indication of the relative position of this 'child'\n            component among all its 'sibling' components.  Sibling\n            components are defined as entPhysicalEntries that share the\n            same instance values of each of the entPhysicalContainedIn\n            and entPhysicalClass objects.\n\n            An NMS can use this object to identify the relative ordering\n            for all sibling components of a particular parent\n            (identified by the entPhysicalContainedIn instance in each\n            sibling entry).\n\n            If possible, this value should match any external labeling\n            of the physical component.  For example, for a container\n            (e.g., card slot) labeled as 'slot #3',\n            entPhysicalParentRelPos should have the value '3'.  Note\n            that the entPhysicalEntry for the module plugged in slot 3\n            should have an entPhysicalParentRelPos value of '1'.\n\n            If the physical position of this component does not match\n            any external numbering or clearly visible ordering, then\n            user documentation or other external reference material\n            should be used to determine the parent-relative position.\n            If this is not possible, then the agent should assign a\n            consistent (but possibly arbitrary) ordering to a given set\n            of 'sibling' components, perhaps based on internal\n            representation of the components.\n\n\n            If the agent cannot determine the parent-relative position\n            for some reason, or if the associated value of\n            entPhysicalContainedIn is '0', then the value '-1' is\n            returned.  Otherwise, a non-negative integer is returned,\n            indicating the parent-relative position of this physical\n            entity.\n\n            Parent-relative ordering normally starts from '1' and\n            continues to 'N', where 'N' represents the highest\n            positioned child entity.  However, if the physical entities\n            (e.g., slots) are labeled from a starting position of zero,\n            then the first sibling should be associated with an\n            entPhysicalParentRelPos value of '0'.  Note that this\n            ordering may be sparse or dense, depending on agent\n            implementation.\n\n            The actual values returned are not globally meaningful, as\n            each 'parent' component may use different numbering\n            algorithms.  The ordering is only meaningful among siblings\n            of the same parent component.\n\n            The agent should retain parent-relative position values\n            across reboots, either through algorithmic assignment or use\n            of non-volatile storage.")
entPhysicalName = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 7), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalName.setDescription("The textual name of the physical entity.  The value of this\n            object should be the name of the component as assigned by\n            the local device and should be suitable for use in commands\n            entered at the device's `console'.  This might be a text\n            name (e.g., `console') or a simple component number (e.g.,\n            port or module number, such as `1'), depending on the\n            physical component naming syntax of the device.\n\n            If there is no local name, or if this object is otherwise\n            not applicable, then this object contains a zero-length\n            string.\n\n            Note that the value of entPhysicalName for two physical\n            entities will be the same in the event that the console\n            interface does not distinguish between them, e.g., slot-1\n            and the card in slot-1.")
entPhysicalHardwareRev = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 8), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalHardwareRev.setDescription('The vendor-specific hardware revision string for the\n            physical entity.  The preferred value is the hardware\n            revision identifier actually printed on the component itself\n            (if present).\n\n            Note that if revision information is stored internally in a\n            non-printable (e.g., binary) format, then the agent must\n            convert such information to a printable format, in an\n            implementation-specific manner.\n\n            If no specific hardware revision string is associated with\n            the physical component, or if this information is unknown to\n            the agent, then this object will contain a zero-length\n            string.')
entPhysicalFirmwareRev = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 9), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalFirmwareRev.setDescription('The vendor-specific firmware revision string for the\n            physical entity.\n\n            Note that if revision information is stored internally in a\n            non-printable (e.g., binary) format, then the agent must\n            convert such information to a printable format, in an\n            implementation-specific manner.\n\n            If no specific firmware programs are associated with the\n            physical component, or if this information is unknown to the\n            agent, then this object will contain a zero-length string.')
entPhysicalSoftwareRev = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 10), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalSoftwareRev.setDescription('The vendor-specific software revision string for the\n            physical entity.\n\n            Note that if revision information is stored internally in a\n\n\n            non-printable (e.g., binary) format, then the agent must\n            convert such information to a printable format, in an\n            implementation-specific manner.\n\n            If no specific software programs are associated with the\n            physical component, or if this information is unknown to the\n            agent, then this object will contain a zero-length string.')
entPhysicalSerialNum = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 11), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: entPhysicalSerialNum.setDescription("The vendor-specific serial number string for the physical\n            entity.  The preferred value is the serial number string\n            actually printed on the component itself (if present).\n\n            On the first instantiation of an physical entity, the value\n            of entPhysicalSerialNum associated with that entity is set\n            to the correct vendor-assigned serial number, if this\n            information is available to the agent.  If a serial number\n            is unknown or non-existent, the entPhysicalSerialNum will be\n            set to a zero-length string instead.\n\n            Note that implementations that can correctly identify the\n            serial numbers of all installed physical entities do not\n            need to provide write access to the entPhysicalSerialNum\n            object.  Agents which cannot provide non-volatile storage\n            for the entPhysicalSerialNum strings are not required to\n            implement write access for this object.\n\n            Not every physical component will have a serial number, or\n            even need one.  Physical entities for which the associated\n            value of the entPhysicalIsFRU object is equal to 'false(2)'\n            (e.g., the repeater ports within a repeater module), do not\n            need their own unique serial number.  An agent does not have\n            to provide write access for such entities, and may return a\n            zero-length string.\n\n            If write access is implemented for an instance of\n            entPhysicalSerialNum, and a value is written into the\n            instance, the agent must retain the supplied value in the\n            entPhysicalSerialNum instance (associated with the same\n            physical entity) for as long as that entity remains\n            instantiated.  This includes instantiations across all\n            re-initializations/reboots of the network management system,\n            including those resulting in a change of the physical\n\n\n            entity's entPhysicalIndex value.")
entPhysicalMfgName = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 12), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalMfgName.setDescription('The name of the manufacturer of this physical component.\n            The preferred value is the manufacturer name string actually\n            printed on the component itself (if present).\n\n            Note that comparisons between instances of the\n            entPhysicalModelName, entPhysicalFirmwareRev,\n            entPhysicalSoftwareRev, and the entPhysicalSerialNum\n            objects, are only meaningful amongst entPhysicalEntries with\n            the same value of entPhysicalMfgName.\n\n            If the manufacturer name string associated with the physical\n            component is unknown to the agent, then this object will\n            contain a zero-length string.')
entPhysicalModelName = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 13), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalModelName.setDescription('The vendor-specific model name identifier string associated\n            with this physical component.  The preferred value is the\n            customer-visible part number, which may be printed on the\n            component itself.\n\n            If the model name string associated with the physical\n            component is unknown to the agent, then this object will\n            contain a zero-length string.')
entPhysicalAlias = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 14), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: entPhysicalAlias.setDescription("This object is an 'alias' name for the physical entity, as\n            specified by a network manager, and provides a non-volatile\n            'handle' for the physical entity.\n\n            On the first instantiation of a physical entity, the value\n\n\n            of entPhysicalAlias associated with that entity is set to\n            the zero-length string.  However, the agent may set the\n            value to a locally unique default value, instead of a\n            zero-length string.\n\n            If write access is implemented for an instance of\n            entPhysicalAlias, and a value is written into the instance,\n            the agent must retain the supplied value in the\n            entPhysicalAlias instance (associated with the same physical\n            entity) for as long as that entity remains instantiated.\n            This includes instantiations across all\n            re-initializations/reboots of the network management system,\n            including those resulting in a change of the physical\n            entity's entPhysicalIndex value.")
entPhysicalAssetID = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 15), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: entPhysicalAssetID.setDescription("This object is a user-assigned asset tracking identifier\n            (as specified by a network manager) for the physical entity,\n            and provides non-volatile storage of this information.\n\n            On the first instantiation of a physical entity, the value\n            of entPhysicalAssetID associated with that entity is set to\n            the zero-length string.\n\n            Not every physical component will have an asset tracking\n            identifier, or even need one.  Physical entities for which\n            the associated value of the entPhysicalIsFRU object is equal\n            to 'false(2)' (e.g., the repeater ports within a repeater\n            module), do not need their own unique asset tracking\n            identifier.  An agent does not have to provide write access\n            for such entities, and may instead return a zero-length\n            string.\n\n            If write access is implemented for an instance of\n            entPhysicalAssetID, and a value is written into the\n            instance, the agent must retain the supplied value in the\n            entPhysicalAssetID instance (associated with the same\n            physical entity) for as long as that entity remains\n            instantiated.  This includes instantiations across all\n            re-initializations/reboots of the network management system,\n            including those resulting in a change of the physical\n            entity's entPhysicalIndex value.\n\n\n            If no asset tracking information is associated with the\n            physical component, then this object will contain a\n            zero-length string.")
entPhysicalIsFRU = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 16), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalIsFRU.setDescription("This object indicates whether or not this physical entity\n            is considered a 'field replaceable unit' by the vendor.  If\n            this object contains the value 'true(1)' then this\n            entPhysicalEntry identifies a field replaceable unit.  For\n            all entPhysicalEntries that represent components\n            permanently contained within a field replaceable unit, the\n            value 'false(2)' should be returned for this object.")
entPhysicalMfgDate = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 17), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalMfgDate.setDescription("This object contains the date of manufacturing of the\n            managed entity.  If the manufacturing date is unknown or not\n            supported, the object is not instantiated.  The special\n            value '0000000000000000'H may also be returned in this\n            case.")
entPhysicalUris = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 1, 1, 1, 18), OctetString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: entPhysicalUris.setDescription('This object contains additional identification information\n            about the physical entity.  The object contains URIs and,\n            therefore, the syntax of this object must conform to RFC\n            3986, section 2.\n\n            Multiple URIs may be present and are separated by white\n            space characters.  Leading and trailing white space\n            characters are ignored.\n\n            If no additional identification information is known\n            about the physical entity or supported, the object is not\n            instantiated.  A zero length octet string may also be\n\n\n            returned in this case.')
entLogicalTable = MibTable((1, 3, 6, 1, 2, 1, 47, 1, 2, 1), )
if mibBuilder.loadTexts: entLogicalTable.setDescription('This table contains one row per logical entity.  For agents\n            that implement more than one naming scope, at least one\n            entry must exist.  Agents which instantiate all MIB objects\n            within a single naming scope are not required to implement\n            this table.')
entLogicalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1), ).setIndexNames((0, "ENTITY-MIB", "entLogicalIndex"))
if mibBuilder.loadTexts: entLogicalEntry.setDescription('Information about a particular logical entity.  Entities\n            may be managed by this agent or other SNMP agents (possibly)\n            in the same chassis.')
entLogicalIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: entLogicalIndex.setDescription('The value of this object uniquely identifies the logical\n            entity.  The value should be a small positive integer; index\n            values for different logical entities are not necessarily\n            contiguous.')
entLogicalDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLogicalDescr.setDescription("A textual description of the logical entity.  This object\n            should contain a string that identifies the manufacturer's\n            name for the logical entity, and should be set to a distinct\n            value for each version of the logical entity.")
entLogicalType = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1, 3), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLogicalType.setDescription("An indication of the type of logical entity.  This will\n            typically be the OBJECT IDENTIFIER name of the node in the\n            SMI's naming hierarchy which represents the major MIB\n            module, or the majority of the MIB modules, supported by the\n            logical entity.  For example:\n               a logical entity of a regular host/router -> mib-2\n               a logical entity of a 802.1d bridge -> dot1dBridge\n               a logical entity of a 802.3 repeater -> snmpDot3RptrMgmt\n            If an appropriate node in the SMI's naming hierarchy cannot\n            be identified, the value 'mib-2' should be used.")
entLogicalCommunity = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLogicalCommunity.setDescription("An SNMPv1 or SNMPv2C community-string, which can be used to\n            access detailed management information for this logical\n            entity.  The agent should allow read access with this\n            community string (to an appropriate subset of all managed\n            objects) and may also return a community string based on the\n            privileges of the request used to read this object.  Note\n            that an agent may return a community string with read-only\n            privileges, even if this object is accessed with a\n            read-write community string.  However, the agent must take\n\n\n            care not to return a community string that allows more\n            privileges than the community string used to access this\n            object.\n\n            A compliant SNMP agent may wish to conserve naming scopes by\n            representing multiple logical entities in a single 'default'\n            naming scope.  This is possible when the logical entities,\n            represented by the same value of entLogicalCommunity, have\n            no object instances in common.  For example, 'bridge1' and\n            'repeater1' may be part of the main naming scope, but at\n            least one additional community string is needed to represent\n            'bridge2' and 'repeater2'.\n\n            Logical entities 'bridge1' and 'repeater1' would be\n            represented by sysOREntries associated with the 'default'\n            naming scope.\n\n            For agents not accessible via SNMPv1 or SNMPv2C, the value\n            of this object is the empty string.  This object may also\n            contain an empty string if a community string has not yet\n            been assigned by the agent, or if no community string with\n            suitable access rights can be returned for a particular SNMP\n            request.\n\n            Note that this object is deprecated.  Agents which implement\n            SNMPv3 access should use the entLogicalContextEngineID and\n            entLogicalContextName objects to identify the context\n            associated with each logical entity.  SNMPv3 agents may\n            return a zero-length string for this object, or may continue\n            to return a community string (e.g., tri-lingual agent\n            support).")
entLogicalTAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1, 5), TAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLogicalTAddress.setDescription("The transport service address by which the logical entity\n            receives network management traffic, formatted according to\n            the corresponding value of entLogicalTDomain.\n\n            For snmpUDPDomain, a TAddress is 6 octets long: the initial\n            4 octets contain the IP-address in network-byte order and\n            the last 2 contain the UDP port in network-byte order.\n            Consult 'Transport Mappings for the Simple Network\n            Management Protocol' (STD 62, RFC 3417 [RFC3417]) for\n            further information on snmpUDPDomain.")
entLogicalTDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1, 6), TDomain()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLogicalTDomain.setDescription("Indicates the kind of transport service by which the\n            logical entity receives network management traffic.\n            Possible values for this object are presently found in the\n            Transport Mappings for Simple Network Management Protocol'\n            (STD 62, RFC 3417 [RFC3417]).")
entLogicalContextEngineID = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1, 7), SnmpEngineIdOrNone()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLogicalContextEngineID.setDescription("The authoritative contextEngineID that can be used to send\n            an SNMP message concerning information held by this logical\n            entity, to the address specified by the associated\n            'entLogicalTAddress/entLogicalTDomain' pair.\n\n            This object, together with the associated\n            entLogicalContextName object, defines the context associated\n            with a particular logical entity, and allows access to SNMP\n            engines identified by a contextEngineId and contextName\n            pair.\n\n            If no value has been configured by the agent, a zero-length\n            string is returned, or the agent may choose not to\n            instantiate this object at all.")
entLogicalContextName = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 2, 1, 1, 8), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLogicalContextName.setDescription("The contextName that can be used to send an SNMP message\n            concerning information held by this logical entity, to the\n            address specified by the associated\n            'entLogicalTAddress/entLogicalTDomain' pair.\n\n            This object, together with the associated\n            entLogicalContextEngineID object, defines the context\n            associated with a particular logical entity, and allows\n\n\n            access to SNMP engines identified by a contextEngineId and\n            contextName pair.\n\n            If no value has been configured by the agent, a zero-length\n            string is returned, or the agent may choose not to\n            instantiate this object at all.")
entLPMappingTable = MibTable((1, 3, 6, 1, 2, 1, 47, 1, 3, 1), )
if mibBuilder.loadTexts: entLPMappingTable.setDescription('This table contains zero or more rows of logical entity to\n            physical equipment associations.  For each logical entity\n            known by this agent, there are zero or more mappings to the\n            physical resources, which are used to realize that logical\n            entity.\n\n            An agent should limit the number and nature of entries in\n            this table such that only meaningful and non-redundant\n            information is returned.  For example, in a system that\n            contains a single power supply, mappings between logical\n            entities and the power supply are not useful and should not\n            be included.\n\n            Also, only the most appropriate physical component, which is\n            closest to the root of a particular containment tree, should\n            be identified in an entLPMapping entry.\n\n            For example, suppose a bridge is realized on a particular\n            module, and all ports on that module are ports on this\n            bridge.  A mapping between the bridge and the module would\n            be useful, but additional mappings between the bridge and\n            each of the ports on that module would be redundant (because\n            the entPhysicalContainedIn hierarchy can provide the same\n            information).  On the other hand, if more than one bridge\n            were utilizing ports on this module, then mappings between\n            each bridge and the ports it used would be appropriate.\n\n            Also, in the case of a single backplane repeater, a mapping\n            for the backplane to the single repeater entity is not\n            necessary.')
entLPMappingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 47, 1, 3, 1, 1), ).setIndexNames((0, "ENTITY-MIB", "entLogicalIndex"), (0, "ENTITY-MIB", "entLPPhysicalIndex"))
if mibBuilder.loadTexts: entLPMappingEntry.setDescription('Information about a particular logical entity to physical\n            equipment association.  Note that the nature of the\n            association is not specifically identified in this entry.\n            It is expected that sufficient information exists in the\n            MIBs used to manage a particular logical entity to infer how\n            physical component information is utilized.')
entLPPhysicalIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 3, 1, 1, 1), PhysicalIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLPPhysicalIndex.setDescription('The value of this object identifies the index value of a\n            particular entPhysicalEntry associated with the indicated\n            entLogicalEntity.')
entAliasMappingTable = MibTable((1, 3, 6, 1, 2, 1, 47, 1, 3, 2), )
if mibBuilder.loadTexts: entAliasMappingTable.setDescription("This table contains zero or more rows, representing\n            mappings of logical entity and physical component to\n            external MIB identifiers.  Each physical port in the system\n            may be associated with a mapping to an external identifier,\n            which itself is associated with a particular logical\n            entity's naming scope.  A 'wildcard' mechanism is provided\n            to indicate that an identifier is associated with more than\n            one logical entity.")
entAliasMappingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 47, 1, 3, 2, 1), ).setIndexNames((0, "ENTITY-MIB", "entPhysicalIndex"), (0, "ENTITY-MIB", "entAliasLogicalIndexOrZero"))
if mibBuilder.loadTexts: entAliasMappingEntry.setDescription("Information about a particular physical equipment, logical\n\n\n            entity to external identifier binding.  Each logical\n            entity/physical component pair may be associated with one\n            alias mapping.  The logical entity index may also be used as\n            a 'wildcard' (refer to the entAliasLogicalIndexOrZero object\n            DESCRIPTION clause for details.)\n\n            Note that only entPhysicalIndex values that represent\n            physical ports (i.e., associated entPhysicalClass value is\n            'port(10)') are permitted to exist in this table.")
entAliasLogicalIndexOrZero = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 3, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647)))
if mibBuilder.loadTexts: entAliasLogicalIndexOrZero.setDescription("The value of this object identifies the logical entity\n            that defines the naming scope for the associated instance\n            of the 'entAliasMappingIdentifier' object.\n\n            If this object has a non-zero value, then it identifies the\n            logical entity named by the same value of entLogicalIndex.\n\n            If this object has a value of zero, then the mapping between\n            the physical component and the alias identifier for this\n            entAliasMapping entry is associated with all unspecified\n            logical entities.  That is, a value of zero (the default\n            mapping) identifies any logical entity that does not have\n            an explicit entry in this table for a particular\n            entPhysicalIndex/entAliasMappingIdentifier pair.\n\n            For example, to indicate that a particular interface (e.g.,\n            physical component 33) is identified by the same value of\n            ifIndex for all logical entities, the following instance\n            might exist:\n\n                    entAliasMappingIdentifier.33.0 = ifIndex.5\n\n            In the event an entPhysicalEntry is associated differently\n            for some logical entities, additional entAliasMapping\n            entries may exist, e.g.:\n\n\n                    entAliasMappingIdentifier.33.0 = ifIndex.6\n                    entAliasMappingIdentifier.33.4 =  ifIndex.1\n                    entAliasMappingIdentifier.33.5 =  ifIndex.1\n                    entAliasMappingIdentifier.33.10 = ifIndex.12\n\n            Note that entries with non-zero entAliasLogicalIndexOrZero\n            index values have precedence over zero-indexed entries.  In\n            this example, all logical entities except 4, 5, and 10,\n            associate physical entity 33 with ifIndex.6.")
entAliasMappingIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 3, 2, 1, 2), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entAliasMappingIdentifier.setDescription("The value of this object identifies a particular conceptual\n            row associated with the indicated entPhysicalIndex and\n            entLogicalIndex pair.\n\n            Because only physical ports are modeled in this table, only\n            entries that represent interfaces or ports are allowed.  If\n            an ifEntry exists on behalf of a particular physical port,\n            then this object should identify the associated 'ifEntry'.\n            For repeater ports, the appropriate row in the\n            'rptrPortGroupTable' should be identified instead.\n\n            For example, suppose a physical port was represented by\n            entPhysicalEntry.3, entLogicalEntry.15 existed for a\n            repeater, and entLogicalEntry.22 existed for a bridge.  Then\n            there might be two related instances of\n            entAliasMappingIdentifier:\n               entAliasMappingIdentifier.3.15 == rptrPortGroupIndex.5.2\n               entAliasMappingIdentifier.3.22 == ifIndex.17\n            It is possible that other mappings (besides interfaces and\n            repeater ports) may be defined in the future, as required.\n\n            Bridge ports are identified by examining the Bridge MIB and\n            appropriate ifEntries associated with each 'dot1dBasePort',\n            and are thus not represented in this table.")
entPhysicalContainsTable = MibTable((1, 3, 6, 1, 2, 1, 47, 1, 3, 3), )
if mibBuilder.loadTexts: entPhysicalContainsTable.setDescription("A table that exposes the container/'containee'\n            relationships between physical entities.  This table\n            provides all the information found by constructing the\n            virtual containment tree for a given entPhysicalTable, but\n            in a more direct format.\n\n            In the event a physical entity is contained by more than one\n            other physical entity (e.g., double-wide modules), this\n            table should include these additional mappings, which cannot\n            be represented in the entPhysicalTable virtual containment\n            tree.")
entPhysicalContainsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 47, 1, 3, 3, 1), ).setIndexNames((0, "ENTITY-MIB", "entPhysicalIndex"), (0, "ENTITY-MIB", "entPhysicalChildIndex"))
if mibBuilder.loadTexts: entPhysicalContainsEntry.setDescription("A single container/'containee' relationship.")
entPhysicalChildIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 47, 1, 3, 3, 1, 1), PhysicalIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhysicalChildIndex.setDescription('The value of entPhysicalIndex for the contained physical\n            entity.')
entLastChangeTime = MibScalar((1, 3, 6, 1, 2, 1, 47, 1, 4, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entLastChangeTime.setDescription('The value of sysUpTime at the time a conceptual row is\n            created, modified, or deleted in any of these tables:\n                    - entPhysicalTable\n                    - entLogicalTable\n                    - entLPMappingTable\n                    - entAliasMappingTable\n\n\n                    - entPhysicalContainsTable\n            ')
entityMIBTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 2))
entityMIBTrapPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 2, 0))
entConfigChange = NotificationType((1, 3, 6, 1, 2, 1, 47, 2, 0, 1)).setObjects(*())
if mibBuilder.loadTexts: entConfigChange.setDescription("An entConfigChange notification is generated when the value\n            of entLastChangeTime changes.  It can be utilized by an NMS\n            to trigger logical/physical entity table maintenance polls.\n\n            An agent should not generate more than one entConfigChange\n            'notification-event' in a given time interval (five seconds\n            is the suggested default).  A 'notification-event' is the\n            transmission of a single trap or inform PDU to a list of\n            notification destinations.\n\n            If additional configuration changes occur within the\n            throttling period, then notification-events for these\n            changes should be suppressed by the agent until the current\n            throttling period expires.  At the end of a throttling\n            period, one notification-event should be generated if any\n            configuration changes occurred since the start of the\n            throttling period.  In such a case, another throttling\n            period is started right away.\n\n            An NMS should periodically check the value of\n            entLastChangeTime to detect any missed entConfigChange\n            notification-events, e.g., due to throttling or transmission\n            loss.")
entityConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 3))
entityCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 3, 1))
entityGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 47, 3, 2))
entityCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 47, 3, 1, 1)).setObjects(*(("ENTITY-MIB", "entityPhysicalGroup"), ("ENTITY-MIB", "entityLogicalGroup"), ("ENTITY-MIB", "entityMappingGroup"), ("ENTITY-MIB", "entityGeneralGroup"), ("ENTITY-MIB", "entityNotificationsGroup"),))
if mibBuilder.loadTexts: entityCompliance.setDescription('The compliance statement for SNMP entities that implement\n            version 1 of the Entity MIB.')
entity2Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 47, 3, 1, 2)).setObjects(*(("ENTITY-MIB", "entityPhysicalGroup"), ("ENTITY-MIB", "entityPhysical2Group"), ("ENTITY-MIB", "entityGeneralGroup"), ("ENTITY-MIB", "entityNotificationsGroup"), ("ENTITY-MIB", "entityLogical2Group"), ("ENTITY-MIB", "entityMappingGroup"),))
if mibBuilder.loadTexts: entity2Compliance.setDescription('The compliance statement for SNMP entities that implement\n            version 2 of the Entity MIB.')
entity3Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 47, 3, 1, 3)).setObjects(*(("ENTITY-MIB", "entityPhysicalGroup"), ("ENTITY-MIB", "entityPhysical2Group"), ("ENTITY-MIB", "entityPhysical3Group"), ("ENTITY-MIB", "entityGeneralGroup"), ("ENTITY-MIB", "entityNotificationsGroup"), ("ENTITY-MIB", "entityLogical2Group"), ("ENTITY-MIB", "entityMappingGroup"),))
if mibBuilder.loadTexts: entity3Compliance.setDescription('The compliance statement for SNMP entities that implement\n            version 3 of the Entity MIB.')
entityPhysicalGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 47, 3, 2, 1)).setObjects(*(("ENTITY-MIB", "entPhysicalDescr"), ("ENTITY-MIB", "entPhysicalVendorType"), ("ENTITY-MIB", "entPhysicalContainedIn"), ("ENTITY-MIB", "entPhysicalClass"), ("ENTITY-MIB", "entPhysicalParentRelPos"), ("ENTITY-MIB", "entPhysicalName"),))
if mibBuilder.loadTexts: entityPhysicalGroup.setDescription('The collection of objects used to represent physical\n            system components, for which a single agent provides\n            management information.')
entityLogicalGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 47, 3, 2, 2)).setObjects(*(("ENTITY-MIB", "entLogicalDescr"), ("ENTITY-MIB", "entLogicalType"), ("ENTITY-MIB", "entLogicalCommunity"), ("ENTITY-MIB", "entLogicalTAddress"), ("ENTITY-MIB", "entLogicalTDomain"),))
if mibBuilder.loadTexts: entityLogicalGroup.setDescription('The collection of objects used to represent the list of\n            logical entities, for which a single agent provides\n            management information.')
entityMappingGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 47, 3, 2, 3)).setObjects(*(("ENTITY-MIB", "entLPPhysicalIndex"), ("ENTITY-MIB", "entAliasMappingIdentifier"), ("ENTITY-MIB", "entPhysicalChildIndex"),))
if mibBuilder.loadTexts: entityMappingGroup.setDescription('The collection of objects used to represent the\n            associations between multiple logical entities, physical\n            components, interfaces, and port identifiers, for which a\n            single agent provides management information.')
entityGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 47, 3, 2, 4)).setObjects(*(("ENTITY-MIB", "entLastChangeTime"),))
if mibBuilder.loadTexts: entityGeneralGroup.setDescription('The collection of objects used to represent general entity\n            information, for which a single agent provides management\n            information.')
entityNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 47, 3, 2, 5)).setObjects(*(("ENTITY-MIB", "entConfigChange"),))
if mibBuilder.loadTexts: entityNotificationsGroup.setDescription('The collection of notifications used to indicate Entity MIB\n            data consistency and general status information.')
entityPhysical2Group = ObjectGroup((1, 3, 6, 1, 2, 1, 47, 3, 2, 6)).setObjects(*(("ENTITY-MIB", "entPhysicalHardwareRev"), ("ENTITY-MIB", "entPhysicalFirmwareRev"), ("ENTITY-MIB", "entPhysicalSoftwareRev"), ("ENTITY-MIB", "entPhysicalSerialNum"), ("ENTITY-MIB", "entPhysicalMfgName"), ("ENTITY-MIB", "entPhysicalModelName"), ("ENTITY-MIB", "entPhysicalAlias"), ("ENTITY-MIB", "entPhysicalAssetID"), ("ENTITY-MIB", "entPhysicalIsFRU"),))
if mibBuilder.loadTexts: entityPhysical2Group.setDescription('The collection of objects used to represent physical\n            system components, for which a single agent provides\n            management information.  This group augments the objects\n            contained in the entityPhysicalGroup.')
entityLogical2Group = ObjectGroup((1, 3, 6, 1, 2, 1, 47, 3, 2, 7)).setObjects(*(("ENTITY-MIB", "entLogicalDescr"), ("ENTITY-MIB", "entLogicalType"), ("ENTITY-MIB", "entLogicalTAddress"), ("ENTITY-MIB", "entLogicalTDomain"), ("ENTITY-MIB", "entLogicalContextEngineID"), ("ENTITY-MIB", "entLogicalContextName"),))
if mibBuilder.loadTexts: entityLogical2Group.setDescription('The collection of objects used to represent the\n            list of logical entities, for which a single SNMP entity\n            provides management information.')
entityPhysical3Group = ObjectGroup((1, 3, 6, 1, 2, 1, 47, 3, 2, 8)).setObjects(*(("ENTITY-MIB", "entPhysicalMfgDate"), ("ENTITY-MIB", "entPhysicalUris"),))
if mibBuilder.loadTexts: entityPhysical3Group.setDescription('The collection of objects used to represent physical\n            system components, for which a single agent provides\n            management information.  This group augments the objects\n            contained in the entityPhysicalGroup.')
mibBuilder.exportSymbols("ENTITY-MIB", entAliasLogicalIndexOrZero=entAliasLogicalIndexOrZero, entityMIB=entityMIB, entPhysicalAlias=entPhysicalAlias, entLogicalType=entLogicalType, entPhysicalIsFRU=entPhysicalIsFRU, entPhysicalUris=entPhysicalUris, entPhysicalContainsEntry=entPhysicalContainsEntry, entPhysicalHardwareRev=entPhysicalHardwareRev, entConfigChange=entConfigChange, entityLogical=entityLogical, entPhysicalTable=entPhysicalTable, entLogicalTAddress=entLogicalTAddress, PhysicalClass=PhysicalClass, entAliasMappingTable=entAliasMappingTable, entPhysicalContainsTable=entPhysicalContainsTable, entLPPhysicalIndex=entLPPhysicalIndex, entAliasMappingIdentifier=entAliasMappingIdentifier, entLPMappingEntry=entLPMappingEntry, entLogicalContextName=entLogicalContextName, entLogicalContextEngineID=entLogicalContextEngineID, entityPhysical2Group=entityPhysical2Group, entPhysicalDescr=entPhysicalDescr, entPhysicalChildIndex=entPhysicalChildIndex, entLogicalIndex=entLogicalIndex, PhysicalIndex=PhysicalIndex, entPhysicalFirmwareRev=entPhysicalFirmwareRev, entity3Compliance=entity3Compliance, entPhysicalParentRelPos=entPhysicalParentRelPos, entPhysicalMfgDate=entPhysicalMfgDate, entityLogical2Group=entityLogical2Group, entPhysicalMfgName=entPhysicalMfgName, entLogicalDescr=entLogicalDescr, entPhysicalContainedIn=entPhysicalContainedIn, entLastChangeTime=entLastChangeTime, entityPhysical3Group=entityPhysical3Group, entAliasMappingEntry=entAliasMappingEntry, entityMIBTraps=entityMIBTraps, entLogicalEntry=entLogicalEntry, entity2Compliance=entity2Compliance, entPhysicalName=entPhysicalName, entPhysicalAssetID=entPhysicalAssetID, PYSNMP_MODULE_ID=entityMIB, entityMIBObjects=entityMIBObjects, entLogicalTDomain=entLogicalTDomain, entPhysicalEntry=entPhysicalEntry, entityCompliances=entityCompliances, entLogicalTable=entLogicalTable, entityConformance=entityConformance, entPhysicalModelName=entPhysicalModelName, entityGroups=entityGroups, entityPhysicalGroup=entityPhysicalGroup, entityGeneral=entityGeneral, entLPMappingTable=entLPMappingTable, entPhysicalSerialNum=entPhysicalSerialNum, entityMIBTrapPrefix=entityMIBTrapPrefix, entityCompliance=entityCompliance, entityPhysical=entityPhysical, entPhysicalIndex=entPhysicalIndex, entityNotificationsGroup=entityNotificationsGroup, entityMappingGroup=entityMappingGroup, entPhysicalSoftwareRev=entPhysicalSoftwareRev, entityMapping=entityMapping, PhysicalIndexOrZero=PhysicalIndexOrZero, entPhysicalClass=entPhysicalClass, entityGeneralGroup=entityGeneralGroup, SnmpEngineIdOrNone=SnmpEngineIdOrNone, entLogicalCommunity=entLogicalCommunity, entPhysicalVendorType=entPhysicalVendorType, entityLogicalGroup=entityLogicalGroup)



#
# PySNMP MIB module NET-SNMP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/NET-SNMP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:22:30 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( ObjectIdentity, iso, Counter64, NotificationType, IpAddress, Integer32, enterprises, MibScalar, MibTable, MibTableRow, MibTableColumn, MibIdentifier, TimeTicks, Gauge32, Counter32, ModuleIdentity, Unsigned32, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ObjectIdentity", "iso", "Counter64", "NotificationType", "IpAddress", "Integer32", "enterprises", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "MibIdentifier", "TimeTicks", "Gauge32", "Counter32", "ModuleIdentity", "Unsigned32", "Bits")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
netSnmp = ModuleIdentity((1, 3, 6, 1, 4, 1, 8072)).setRevisions(("2002-01-30 00:00",))
if mibBuilder.loadTexts: netSnmp.setLastUpdated('200201300000Z')
if mibBuilder.loadTexts: netSnmp.setOrganization('www.net-snmp.org')
if mibBuilder.loadTexts: netSnmp.setContactInfo('postal:   Wes Hardaker\n                    P.O. Box 382\n                    Davis CA  95617\n\n          email:    net-snmp-coders@lists.sourceforge.net')
if mibBuilder.loadTexts: netSnmp.setDescription('Top-level infrastructure of the Net-SNMP project enterprise MIB tree')
netSnmpObjects = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 1))
netSnmpEnumerations = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 3))
netSnmpModuleIDs = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 3, 1))
netSnmpAgentOIDs = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 3, 2))
netSnmpDomains = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 3, 3))
netSnmpExperimental = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 9999))
netSnmpPlaypen = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 9999, 9999))
netSnmpNotificationPrefix = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 4))
netSnmpNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 4, 0))
netSnmpNotificationObjects = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 4, 1))
netSnmpConformance = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 5))
netSnmpCompliances = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 5, 1))
netSnmpGroups = MibIdentifier((1, 3, 6, 1, 4, 1, 8072, 5, 2))
mibBuilder.exportSymbols("NET-SNMP-MIB", netSnmpObjects=netSnmpObjects, PYSNMP_MODULE_ID=netSnmp, netSnmpExperimental=netSnmpExperimental, netSnmpEnumerations=netSnmpEnumerations, netSnmp=netSnmp, netSnmpCompliances=netSnmpCompliances, netSnmpAgentOIDs=netSnmpAgentOIDs, netSnmpDomains=netSnmpDomains, netSnmpConformance=netSnmpConformance, netSnmpModuleIDs=netSnmpModuleIDs, netSnmpPlaypen=netSnmpPlaypen, netSnmpNotificationPrefix=netSnmpNotificationPrefix, netSnmpNotifications=netSnmpNotifications, netSnmpNotificationObjects=netSnmpNotificationObjects, netSnmpGroups=netSnmpGroups)



#
# PySNMP MIB module PPP-SEC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/PPP-SEC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:24:35 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( ppp, ) = mibBuilder.importSymbols("PPP-LCP-MIB", "ppp")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( Bits, Integer32, iso, NotificationType, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, TimeTicks, Counter32, Gauge32, MibIdentifier, IpAddress, Unsigned32, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "Integer32", "iso", "NotificationType", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "TimeTicks", "Counter32", "Gauge32", "MibIdentifier", "IpAddress", "Unsigned32", "ModuleIdentity")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
pppSecurity = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 23, 2))
pppSecurityProtocols = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 23, 2, 1))
pppSecurityPapProtocol = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 23, 2, 1, 1))
pppSecurityChapMD5Protocol = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 23, 2, 1, 2))
pppSecurityConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 23, 2, 2), )
if mibBuilder.loadTexts: pppSecurityConfigTable.setDescription('Table containing the configuration and\n                         preference parameters for PPP Security.')
pppSecurityConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 23, 2, 2, 1), ).setIndexNames((0, "PPP-SEC-MIB", "pppSecurityConfigLink"), (0, "PPP-SEC-MIB", "pppSecurityConfigPreference"))
if mibBuilder.loadTexts: pppSecurityConfigEntry.setDescription('Security configuration information for a\n                         particular PPP link.')
pppSecurityConfigLink = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecurityConfigLink.setDescription("The value of ifIndex that identifies the entry\n                         in the interface table that is associated with\n                         the local PPP entity's link for which this\n                         particular security algorithm shall be\n                         attempted. A value of 0 indicates the default\n                         algorithm - i.e., this entry applies to all\n                         links for which explicit entries in the table\n                         do not exist.")
pppSecurityConfigPreference = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecurityConfigPreference.setDescription('The relative preference of the security\n                         protocol identified by\n                         pppSecurityConfigProtocol. Security protocols\n                         with lower values of\n                         pppSecurityConfigPreference are tried before\n                         protocols with higher values of\n                         pppSecurityConfigPreference.')
pppSecurityConfigProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 2, 1, 3), ObjectIdentifier()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecurityConfigProtocol.setDescription('Identifies the security protocol to be\n                         attempted on the link identified by\n                         pppSecurityConfigLink at the preference level\n                         identified by pppSecurityConfigPreference. ')
pppSecurityConfigStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 2, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("invalid", 1), ("valid", 2),)).clone('valid')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecurityConfigStatus.setDescription('Setting this object to the value invalid(1)\n                         has the effect of invalidating the\n                         corresponding entry in the\n                         pppSecurityConfigTable. It is an\n                         implementation-specific matter as to whether\n                         the agent removes an invalidated entry from the\n                         table.  Accordingly, management stations must\n                         be prepared to receive tabular information from\n                         agents that corresponds to entries not\n                         currently in use.  Proper interpretation of\n                         such entries requires examination of the\n                         relevant pppSecurityConfigStatus object.')
pppSecuritySecretsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 23, 2, 3), )
if mibBuilder.loadTexts: pppSecuritySecretsTable.setDescription('Table containing the identities and secrets\n                         used by the PPP authentication protocols.  As\n                         this table contains secret information, it is\n                         expected that access to this table be limited\n                         to those SNMP Party-Pairs for which a privacy\n                         protocol is in use for all SNMP messages that\n                         the parties exchange.  This table contains both\n                         the ID and secret pair(s) that the local PPP\n                         entity will advertise to the remote entity and\n                         the pair(s) that the local entity will expect\n                         from the remote entity.  This table allows for\n                         multiple id/secret password pairs to be\n                         specified for a particular link by using the\n                         pppSecuritySecretsIdIndex object.')
pppSecuritySecretsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 23, 2, 3, 1), ).setIndexNames((0, "PPP-SEC-MIB", "pppSecuritySecretsLink"), (0, "PPP-SEC-MIB", "pppSecuritySecretsIdIndex"))
if mibBuilder.loadTexts: pppSecuritySecretsEntry.setDescription('Secret information.')
pppSecuritySecretsLink = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppSecuritySecretsLink.setDescription('The link to which this ID/Secret pair applies.\n                         By convention, if the value of this object is 0\n                         then the ID/Secret pair applies to all links.')
pppSecuritySecretsIdIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 3, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppSecuritySecretsIdIndex.setDescription('A unique value for each ID/Secret pair that\n                         has been defined for use on this link.  This\n                         allows multiple ID/Secret pairs to be defined\n                         for each link.  How the local entity selects\n                         which pair to use is a local implementation\n                         decision.')
pppSecuritySecretsDirection = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("local-to-remote", 1), ("remote-to-local", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecuritySecretsDirection.setDescription('This object defines the direction in which a\n                         particular ID/Secret pair is valid.  If this\n                         object is local-to-remote then the local PPP\n                         entity will use the ID/Secret pair when\n                         attempting to authenticate the local PPP entity\n                         to the remote PPP entity.  If this object is\n                         remote-to-local then the local PPP entity will\n                         expect the ID/Secret pair to be used by the\n                         remote PPP entity when the remote PPP entity\n                         attempts to authenticate itself to the local\n                         PPP entity.')
pppSecuritySecretsProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 3, 1, 4), ObjectIdentifier()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecuritySecretsProtocol.setDescription('The security protocol (e.g. CHAP or PAP) to\n                         which this ID/Secret pair applies.')
pppSecuritySecretsIdentity = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 3, 1, 5), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecuritySecretsIdentity.setDescription('The Identity of the ID/Secret pair.  The\n                         actual format, semantics, and use of\n                         pppSecuritySecretsIdentity depends on the\n                         actual security protocol used.  For example, if\n                         pppSecuritySecretsProtocol is\n                         pppSecurityPapProtocol then this object will\n                         contain a PAP Peer-ID. If\n                         pppSecuritySecretsProtocol is\n                         pppSecurityChapMD5Protocol then this object\n                         would contain the CHAP NAME parameter.')
pppSecuritySecretsSecret = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 3, 1, 6), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecuritySecretsSecret.setDescription('The secret of the ID/Secret pair.  The actual\n                         format, semantics, and use of\n                         pppSecuritySecretsSecret depends on the actual\n                         security protocol used.  For example, if\n                         pppSecuritySecretsProtocol is\n                         pppSecurityPapProtocol then this object will\n                         contain a PAP Password. If\n                         pppSecuritySecretsProtocol is\n                         pppSecurityChapMD5Protocol then this object\n                         would contain the CHAP MD5 Secret.')
pppSecuritySecretsStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 2, 3, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("invalid", 1), ("valid", 2),)).clone('valid')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppSecuritySecretsStatus.setDescription('Setting this object to the value invalid(1)\n                         has the effect of invalidating the\n                         corresponding entry in the\n                         pppSecuritySecretsTable. It is an\n                         implementation-specific matter as to whether\n                         the agent removes an invalidated entry from the\n                         table.  Accordingly, management stations must\n                         be prepared to receive tabular information from\n                         agents that corresponds to entries not\n                         currently in use.  Proper interpretation of\n                         such entries requires examination of the\n                         relevant pppSecuritySecretsStatus object.')
mibBuilder.exportSymbols("PPP-SEC-MIB", pppSecuritySecretsEntry=pppSecuritySecretsEntry, pppSecurityConfigLink=pppSecurityConfigLink, pppSecuritySecretsLink=pppSecuritySecretsLink, pppSecuritySecretsProtocol=pppSecuritySecretsProtocol, pppSecurity=pppSecurity, pppSecuritySecretsIdentity=pppSecuritySecretsIdentity, pppSecuritySecretsTable=pppSecuritySecretsTable, pppSecurityConfigEntry=pppSecurityConfigEntry, pppSecurityProtocols=pppSecurityProtocols, pppSecurityConfigTable=pppSecurityConfigTable, pppSecurityConfigPreference=pppSecurityConfigPreference, pppSecurityConfigStatus=pppSecurityConfigStatus, pppSecurityConfigProtocol=pppSecurityConfigProtocol, pppSecuritySecretsStatus=pppSecuritySecretsStatus, pppSecuritySecretsSecret=pppSecuritySecretsSecret, pppSecuritySecretsIdIndex=pppSecuritySecretsIdIndex, pppSecurityPapProtocol=pppSecurityPapProtocol, pppSecurityChapMD5Protocol=pppSecurityChapMD5Protocol, pppSecuritySecretsDirection=pppSecuritySecretsDirection)



#
# PySNMP MIB module IPV6-TC (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IPV6-TC
# Produced by pysmi-0.0.7 at Sun Feb 14 00:18:33 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, SingleValueConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "SingleValueConstraint", "ConstraintsUnion")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( TimeTicks, Counter32, iso, Bits, ObjectIdentity, NotificationType, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, ModuleIdentity, Integer32, Counter64, IpAddress, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "Counter32", "iso", "Bits", "ObjectIdentity", "NotificationType", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "ModuleIdentity", "Integer32", "Counter64", "IpAddress", "MibIdentifier")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
class Ipv6Address(OctetString, TextualConvention):
    displayHint = '2x:'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(16,16)
    fixedLength = 16

class Ipv6AddressPrefix(OctetString, TextualConvention):
    displayHint = '2x:'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,16)

class Ipv6AddressIfIdentifier(OctetString, TextualConvention):
    displayHint = '2x:'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,8)

class Ipv6IfIndex(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,2147483647)

class Ipv6IfIndexOrZero(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

mibBuilder.exportSymbols("IPV6-TC", Ipv6Address=Ipv6Address, Ipv6IfIndex=Ipv6IfIndex, Ipv6AddressPrefix=Ipv6AddressPrefix, Ipv6AddressIfIdentifier=Ipv6AddressIfIdentifier, Ipv6IfIndexOrZero=Ipv6IfIndexOrZero)



#
# PySNMP MIB module RDBMS-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///home/tt/fixed_mibs/RDBMS-MIB
# Produced by pysmi-0.0.2 at Mon Jun 22 23:35:21 2015
# On host cray platform Linux version 2.6.37.6-smp by user tt
# Using Python version 2.7.2 (default, Apr  2 2012, 20:32:47) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( applIndex, ) = mibBuilder.importSymbols("NETWORK-SERVICES-MIB", "applIndex")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, MibTableColumn, MibScalar, MibIdentifier, mib_2, Unsigned32, TimeTicks, Counter64, MibTable, NotificationType, ModuleIdentity, IpAddress, MibTableRow, ModuleIdentity, Gauge32, iso, Bits, ObjectIdentity, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "MibTableColumn", "MibScalar", "MibIdentifier", "mib-2", "Unsigned32", "TimeTicks", "Counter64", "MibTable", "NotificationType", "ModuleIdentity", "IpAddress", "MibTableRow", "ModuleIdentity", "Gauge32", "iso", "Bits", "ObjectIdentity", "Counter32")
( DisplayString, TextualConvention, AutonomousType, DateAndTime, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention", "AutonomousType", "DateAndTime")
rdbmsMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 39))
if mibBuilder.loadTexts: rdbmsMIB.setOrganization('IETF RDBMSMIB Working Group')
if mibBuilder.loadTexts: rdbmsMIB.setContactInfo('           David Brower\n\n                  Postal: The ASK Group, INGRES DBMS Development\n                          1080 Marina Village Parkway\n                          Alameda, CA  94501\n                          US\n\n                     Tel: +1 510 748 3418\n                     Fax: +1 510 748 2770\n\n                  E-mail: daveb@ingres.com')
if mibBuilder.loadTexts: rdbmsMIB.setDescription('The MIB module to describe objects for generic relational\n           databases.')
rdbmsObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 39, 1))
rdbmsDbTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 1), )
if mibBuilder.loadTexts: rdbmsDbTable.setDescription('The table of databases installed on a system.')
rdbmsDbEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 1, 1), ).setIndexNames((0, "RDBMS-MIB", "rdbmsDbIndex"))
if mibBuilder.loadTexts: rdbmsDbEntry.setDescription("An entry for a single database on the host.  Whether a\n           particular database is represented by a row in rdbmsDbTable\n           may be dependent on the activity level of that database,\n           according to the product's implementation.  An instance of\n           rdbmsRelState having the value active, other, or restricted\n           implies that an entry, corresponding to that instance, will\n           be present.")
rdbmsDbIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: rdbmsDbIndex.setDescription('A numeric index, unique among all the databases from all\n           products on this host.  This value is a surrogate for the\n           conceptually unique key, which is {PrivateMibOID,\n           databasename}')
rdbmsDbPrivateMibOID = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 1, 1, 2), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbPrivateMibOID.setDescription('The authoritative identification for the private MIB for\n          this database, presumably based on the vendor, e.g., {\n          enterprises 111 <optional subidentifiers>} for Oracle\n          databases, {enterprises 757 <optional subidentifiers>} for\n          Ingres databases, { enterprises 897 <optional\n          subidentifiers>} for Sybase databases, etc.\n\n          If no OBJECT IDENTIFIER exists for the private MIB, attempts\n          to access this object will return noSuchName (SNMPv1)\n          or noSuchInstance (SNMPv2).')
rdbmsDbVendorName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 1, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbVendorName.setDescription('The name of the vendor whose RDBMS manages this database,\n           for informational purposes.')
rdbmsDbName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 1, 1, 4), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbName.setDescription("The name of this database, in a product specific format.  The\n           product may need to qualify the name in some way to resolve\n           conflicts if it is possible for a database name to be\n           duplicated on a host.  It might be necessary to construct a\n           hierarchical name embedding the RDBMS instance/installation\n           on the host, and/or the owner of the database.  For instance,\n           '/test-installation/database-owner/database-name'.")
rdbmsDbContact = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 1, 1, 5), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsDbContact.setDescription('The textual identification of the contact person for this\n           managed database, together with information on how to contact\n           this person.\n\n           Note: if there is no server associated with this database, an\n           agent may need to keep this in other persistent storage,\n           e.g., a configuration file.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsDbInfoTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 2), )
if mibBuilder.loadTexts: rdbmsDbInfoTable.setDescription('The table of additional information about databases present\n           on the host.')
rdbmsDbInfoEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 2, 1), ).setIndexNames((0, "RDBMS-MIB", "rdbmsDbIndex"))
if mibBuilder.loadTexts: rdbmsDbInfoEntry.setDescription("Information that must be present if the database is actively\n           opened.  If the database is not actively opened, then\n           attempts to access corresponding instances in this table may\n           result in either noSuchName (SNMPv1) or noSuchInstance\n           (SNMPv2).  'Actively opened' means at least one of the\n           rdbmsRelState entries for this database in the rdbmsRelTable\n           is active(2).")
rdbmsDbInfoProductName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 2, 1, 1), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbInfoProductName.setDescription('The textual product name of the server that created or last\n           restructured this database.  The format is product specific.')
rdbmsDbInfoVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 2, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbInfoVersion.setDescription('The version number of the server that created or last\n           restructured this database.  The format is product specific.')
rdbmsDbInfoSizeUnits = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 2, 1, 3), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5,)).clone(namedValues=NamedValues(("bytes", 1), ("kbytes", 2), ("mbytes", 3), ("gbytes", 4), ("tbytes", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbInfoSizeUnits.setDescription('Identification of the units used to measure the size of this\n           database in rdbmsDbInfoSizeAllocated and rdbmsDbInfoSizeUsed.\n           bytes(1) indicates individual bytes, kbytes(2) indicates\n           units of kilobytes, mbytes(3) indicates units of megabytes,\n           gbytes(4) indicates units of gigabytes, and tbytes(5)\n           indicates units of terabytes.  All are binary multiples -- 1K\n           = 1024.  If writable, changes here are reflected in the get\n           values of the associated objects.')
rdbmsDbInfoSizeAllocated = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 2, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsDbInfoSizeAllocated.setDescription('The estimated size of this database (in\n           rdbmsDbInfoSizeUnits), which is the disk space that has been\n           allocated to it and is no longer available to users on this\n           host.  rdbmsDbInfoSize does not necessarily indicate the\n           amount of space actually in use for database data.  Some\n           databases may support extending allocated size, and others\n           may not.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsDbInfoSizeUsed = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbInfoSizeUsed.setDescription('The estimated size of this database, in rdbmsDbInfoSizeUnits,\n           which is actually in use for database data.')
rdbmsDbInfoLastBackup = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 2, 1, 6), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbInfoLastBackup.setDescription('The date and time that the latest complete or partial backup\n           of the database was taken. If a database has never been\n           backed up, then attempts to access this object will\n           result in either noSuchName (SNMPv1) or noSuchInstance\n           (SNMPv2).')
rdbmsDbParamTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 3), )
if mibBuilder.loadTexts: rdbmsDbParamTable.setDescription('The table of configuration parameters for a database.\n           Entries should be populated according to the following\n           guidelines:\n           (1) The value should be specified through administrative\n               (human) intervention.\n           (2) It should be configured on a per-database basis.\n           (3) One of the following is true:\n               (a) The parameter has a non-numeric value;\n               (b) The current value is numeric, but it only changes due\n                   to human intervention;\n               (c) The current value is numeric and dynamic, but the\n                   RDBMS does not track access/allocation failures\n                   related to the parameter;\n               (d) The current value is numeric and dynamic, the\n                   RDBMS tracks changes in access/allocation failures\n                   related to the parameter, but the failure has no\n                   significant impact on RDBMS performance or\n                   availability.\n               (e) The current value is numeric and dynamic, the\n                   RDBMS tracks changes in access/allocation failures\n                   related to the parameter, the failure has\n                   significant impact on RDBMS performance or\n                   availability, and is shown in the\n                   rdbmsDbLimitedResource table.')
rdbmsDbParamEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 3, 1), ).setIndexNames((0, "RDBMS-MIB", "rdbmsDbIndex"), (0, "RDBMS-MIB", "rdbmsDbParamName"), (0, "RDBMS-MIB", "rdbmsDbParamSubIndex"))
if mibBuilder.loadTexts: rdbmsDbParamEntry.setDescription("An entry for a single configuration parameter for a database.\n           Parameters with single values have a subindex value of one.\n           If the parameter is naturally considered to contain a\n           variable number of members of a class, e.g.  members of the\n           DBA user group, or files which are part of the database, then\n           it must be presented as a set of rows.  If, on the other\n           hand, the parameter represents a set of choices from a class,\n           e.g. the permissions on a file or the options chosen out of\n           the set of all options allowed, AND is guaranteed to always\n           fit in the 255 character length of a DisplayString, then it\n           may be presented as a comma separated list with a subindex\n           value of one.  Zero may not be used as a subindex value.\n\n           If the database is not actively opened, then attempts\n           to access corresponding instances in this table may result in\n           either noSuchName (SNMPv1) or noSuchInstance (SNMPv2).\n           'Actively opened' means at least one of the\n           rdbmsRelState entries for this database in the rdbmsRelTable\n           is active(2).")
rdbmsDbParamName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 3, 1, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(1,64)))
if mibBuilder.loadTexts: rdbmsDbParamName.setDescription('The name of a configuration parameter for a database.  This\n           name is product-specific.  The length is limited to 64\n           characters to constrain the number of sub-identifiers needed\n           for instance identification (and to minimize network\n           traffic).')
rdbmsDbParamSubIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 3, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: rdbmsDbParamSubIndex.setDescription('The subindex value for this parameter.  If the parameter is\n           naturally considered to contain a variable number of members\n           of a class, e.g.  members of the DBA user group, or files\n           which are part of the database, then it must be presented as\n           a set of rows.  If, on the other hand, the parameter\n           represents a set of choices from a class, e.g. the\n           permissions on a file or the options chosen out of the set of\n           all options allowed, AND is guaranteed to always fit in the\n           255 character length of a DisplayString, then it may be\n           presented as a comma separated list with a subindex value of\n           one.  Zero may not be used as a value.')
rdbmsDbParamID = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 3, 1, 3), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbParamID.setDescription('The ID of the parameter which may be described in some other\n           MIB (e.g., an enterprise-specific MIB module).  If there is\n           no ID for this rdbmsDbParamName, attempts to access this\n           object will return noSuchName (SNMPv1) or noSuchInstance\n           (SNMPv2).')
rdbmsDbParamCurrValue = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 3, 1, 4), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsDbParamCurrValue.setDescription('The value for a configuration parameter now in effect, the\n           actual setting for the database.  While there may multiple\n           values in the temporal domain of interest (for instance, the\n           value to take effect at the next restart), this is the\n           current setting.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsDbParamComment = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 3, 1, 5), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsDbParamComment.setDescription("Annotation which describes the purpose of a configuration\n           parameter or the reason for a particular parameter's\n           setting.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.")
rdbmsDbLimitedResourceTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 4), )
if mibBuilder.loadTexts: rdbmsDbLimitedResourceTable.setDescription('The table of limited resources that are kept per-database.')
rdbmsDbLimitedResourceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 4, 1), ).setIndexNames((0, "RDBMS-MIB", "rdbmsDbIndex"), (0, "RDBMS-MIB", "rdbmsDbLimitedResourceName"))
if mibBuilder.loadTexts: rdbmsDbLimitedResourceEntry.setDescription("An entry for a single limited resource kept per-database.\n           A limited resource has maximum use determined by a parameter\n           that might or might not be changeable at run time, or visible\n           in the rdbmsDbParamTable. Examples would be the number of\n           available locks, or disk space on a partition.  Arrays of\n           resources are supported through an integer sub index, which\n           should have the value of one for single-instance names.\n\n           Limited resources that are shared across databases, are best\n           put in the rdbmsSvrLimitedResourceTable instead of this one.\n           If the database is not actively opened, then attempts to\n           access corresponding instances in this table may result in\n           either noSuchName (SNMPv1) or noSuchInstance (SNMPv2).\n           'Actively opened' means at least one of the rdbmsRelState\n           entries for this database in the rdbmsRelTable is active(2).")
rdbmsDbLimitedResourceName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 4, 1, 1), DisplayString())
if mibBuilder.loadTexts: rdbmsDbLimitedResourceName.setDescription("The name of the resource, for instance 'global locks' or\n           'locks for the FOO database', or 'data space on /dev/rdsk/5s0\n           for FOO'. The length is limited to 64 characters to constrain\n           the number of sub-identifiers needed for instance\n           identification (and to minimize network traffic).")
rdbmsDbLimitedResourceID = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 4, 1, 2), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbLimitedResourceID.setDescription('The ID of the resource which may be described in some other\n           MIB (e.g., an enterprise-specific MIB module).  If there is\n           no ID for this rdbmsDbLimitedResourceName, attempts to access\n           this object will return noSuchName (SNMPv1) or noSuchInstance\n           (SNMPv2).')
rdbmsDbLimitedResourceLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 4, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsDbLimitedResourceLimit.setDescription('The maximum value the resource use may attain.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsDbLimitedResourceCurrent = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 4, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbLimitedResourceCurrent.setDescription('The current value for the resource.')
rdbmsDbLimitedResourceHighwater = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 4, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbLimitedResourceHighwater.setDescription('The maximum value of the resource seen since applUpTime\n           was reset for the earliest server which has the database\n           actively opened.\n\n           If there are two servers with the database open, and the\n           oldest one dies, the proper way to invalidate the value is by\n           resetting sysUpTime.')
rdbmsDbLimitedResourceFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 4, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsDbLimitedResourceFailures.setDescription('The number of times the system wanted to exceed the limit of\n           the resource since applUpTime was reset for the earliest\n           server which has the database actively opened.\n\n           If there are two servers with the DB open, and the\n           oldest one dies, the proper way to invalidate the value is by\n           resetting sysUpTime.')
rdbmsDbLimitedResourceDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 4, 1, 7), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsDbLimitedResourceDescription.setDescription('A description of the resource and the meaning of the integer\n           units used for Limit, Current, and Highwater.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsSrvTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 5), )
if mibBuilder.loadTexts: rdbmsSrvTable.setDescription('The table of database servers running or installed\n           on a system.')
rdbmsSrvEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 5, 1), ).setIndexNames((0, "RDBMS-MIB", "applIndex"))
if mibBuilder.loadTexts: rdbmsSrvEntry.setDescription("An entry for a single database server.  A server is an\n           independent entity that provides access to one or more\n           databases.  Failure of one does not affect access to\n           databases through any other servers.  There might be one or\n           more servers providing access to a database.  A server may be\n           a 'process' or collection of 'processes', as interpreted by\n           the product.")
rdbmsSrvPrivateMibOID = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 5, 1, 1), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvPrivateMibOID.setDescription('The authoritative identification for the private MIB for this\n           server, presumably based on the vendor, e.g., { enterprises\n           111 <optional subidentifiers>} for Oracle servers, {\n           enterprises 757 <optional subidentifiers>} for Ingres\n           servers, { enterprises 897 <optional subidentifiers>} for\n           Sybase servers, etc.\n\n           If no OBJECT IDENTIFIER exists for the private MIB, attempts\n           to access this object will return noSuchName (SNMPv1)\n           or noSuchInstance (SNMPv2).')
rdbmsSrvVendorName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 5, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvVendorName.setDescription('The name of the vendor whose RDBMS manages this database,\n           for informational purposes.')
rdbmsSrvProductName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 5, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvProductName.setDescription("The product name of this server.  This is normally the\n           vendor's formal name for the product, in product specific\n           format.")
rdbmsSrvContact = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 5, 1, 4), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsSrvContact.setDescription('The textual identification of the contact person for this\n           managed server, together with information on how to contact\n           this person.\n\n           Note: if there is no active server associated with this\n           object, an agent may need to keep this in other persistent\n           storage, e.g., a configuration file.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsSrvInfoTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 6), )
if mibBuilder.loadTexts: rdbmsSrvInfoTable.setDescription("The table of additional information about database servers.\n\n           Entries in this table correspond to applications in the\n           APPLICATION-MIB applTable.  Some objects in that table are\n           application-specific.  When they are associated with an RDBMS\n           server in this table, the objects have the following\n           meanings.\n\n           applName - The name of this server, i.e., the process or\n           group of processes providing access to this database.  The\n           exact format will be product and host specific.\n\n           applVersion - The version number of this server, in product\n           specific format.\n\n           applOperStatus - up(1) means operational and available for\n           general use.  down(2) means the server is not available for\n           use, but is known to the agent.  The other states have broad\n           meaning, and may need to be supplemented by the vendor\n           private MIB.  Halted(3) implies an administrative state of\n           unavailability.  Congested(4) implies a resource or or\n           administrative limit is prohibiting new inbound associations.\n           The 'available soon' description of restarting(5) may include\n           an indeterminate amount of recovery.\n\n           applLastChange is the time the agent noticed the most recent\n           change to applOperStatus.\n\n           applInboundAssociation is the number of currently active\n           local and remote conversations (usually SQL connects).\n\n           applOutboundAssociations is not provided by this MIB.\n\n           applAccumulatedInboundAssociations is the total number of\n           local and remote conversations started since the server came\n           up.\n\n           applAccumulatedOutbound associations is not provided by this\n           MIB.\n\n           applLastInboundActivity is the time the most recent local or\n           remote conversation was attempted or disconnected.\n\n           applLastOutboundActivity is not provided by this MIB.\n\n           applRejectedInboundAssociations is the number of local or\n           remote conversations rejected by the server for\n           administrative reasons or because of resource limitations.\n\n           applFailedOutboundAssociations is not provided by this MIB.")
rdbmsSrvInfoEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 6, 1), ).setIndexNames((0, "RDBMS-MIB", "applIndex"))
if mibBuilder.loadTexts: rdbmsSrvInfoEntry.setDescription("Information that must be present for a single 'up' database\n           server, with visibility determined by the value of the\n           corresponding applOperStatus object.  If an instance of\n           applOperStatus is not up(1), then attempts to access\n           corresponding instances in this table may result in either\n           noSuchName (SNMPv1) or noSuchInstance (SNMPv2) being returned\n           by the agent.")
rdbmsSrvInfoStartupTime = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 1), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoStartupTime.setDescription('The date and time at which this server was last started.')
rdbmsSrvInfoFinishedTransactions = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 2), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoFinishedTransactions.setDescription('The number of transactions visible to this server that have\n           been completed by either commit or abort.  Some database\n           operations, such as read-only queries, may not result in the\n           creation of a transaction.')
rdbmsSrvInfoDiskReads = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoDiskReads.setDescription('The total number of reads of database files issued to the\n           operating system by this server since startup.  Numbers are\n           not comparable between products.  What constitutes a\n           readand how it is accounted is product-specific.')
rdbmsSrvInfoLogicalReads = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoLogicalReads.setDescription('The total number of logical reads of database files made\n           internally by this server since startup.  The values of this\n           object and those of rdbmsSrvInfoDiskReads reveal the effect\n           of caching on read operation. Numbers are not comparable\n           between products, and may only be meaningful when aggregated\n           across all servers sharing a common cache.')
rdbmsSrvInfoDiskWrites = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoDiskWrites.setDescription('The total number of writes to database files issued to the\n           operating system by this server since startup.  Numbers are\n           not comparable between products.')
rdbmsSrvInfoLogicalWrites = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoLogicalWrites.setDescription("The total number of times parts of the database files have\n           been marked 'dirty' and in need of writing to the disk.  This\n           value and rdbmsSrvInfoDiskWrites give some indication of the\n           effect of 'write-behind' strategies in reducing the number of\n           disk writes compared to database operations.  Because the\n           writes may be done by servers other than those marking the\n           parts of the database files dirty, these values may only be\n           meaningful when aggregated across all servers sharing a\n           common cache.  Numbers are not comparable between products.")
rdbmsSrvInfoPageReads = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoPageReads.setDescription("The total number of pages in database files read by this\n           server since startup.  'Pages' are product specific units of\n           disk i/o operations.  This value, along with\n           rdbmsSrvInfoDiskReads, reveals the effect of any grouping\n           read-ahead that may be used to enhance performance of some\n           queries, such as scans.")
rdbmsSrvInfoPageWrites = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoPageWrites.setDescription('The total number of pages in database files written by this\n           server since startup.  Pages are product-specific units of\n           disk I/O.  This value, with rdbmsSrvInfoDiskWrites, shows the\n           effect of write strategies that collapse logical writes of\n           contiguous pages into single calls to the operating system.')
rdbmsSrvInfoDiskOutOfSpaces = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoDiskOutOfSpaces.setDescription('The total number of times the server has been unable to\n           obtain disk space that it wanted, since server startup.  This\n           would be inspected by an agent on receipt of an\n           rdbmsOutOfSpace trap.')
rdbmsSrvInfoHandledRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoHandledRequests.setDescription("The total number of requests made to the server on inbound\n           associations.  The meaning of 'requests' is product specific,\n           and is not comparable between products.\n\n           This is intended to encapsulate high level semantic\n           operations between clients and servers, or between peers.\n           For instance, one request might correspond to a 'select' or\n           an 'insert' statement.  It is not intended to capture disk\n           i/o described in rdbmsSrvInfoDiskReads and\n           rdbmsSrvInfoDiskWrites.")
rdbmsSrvInfoRequestRecvs = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoRequestRecvs.setDescription("The number of receive operations made processing any requests\n           on inbound associations. The meaning of operations is product\n           specific, and is not comparable between products.\n\n           This is intended to capture lower-level i/o operations than\n           shown by HandledRequests, between clients and servers, or\n           between peers.  For instance, it might roughly correspond to\n           the amount of data given with an 'insert' statement.  It is\n           not intended to capture disk i/o described in\n           rdbmsSrvInfoDiskReads and rdbmsSrvInfoDiskWrites.")
rdbmsSrvInfoRequestSends = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoRequestSends.setDescription("The number of send operations made processing requests\n           handled on inbound associations.  The meaning of operations\n           is product specific, and is not comparable between products.\n           This is intended to capture lower-level i/o operations than\n           shown by HandledRequests, between between clients and\n           servers, or between peers.  It might roughly correspond to\n           the number of rows returned by a 'select' statement.  It is\n           not intended to capture disk i/o described in DiskReads.")
rdbmsSrvInfoHighwaterInboundAssociations = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 13), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvInfoHighwaterInboundAssociations.setDescription('The greatest number of inbound associations that have been\n           simultaneously open to this server since startup.')
rdbmsSrvInfoMaxInboundAssociations = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 6, 1, 14), Gauge32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsSrvInfoMaxInboundAssociations.setDescription('The greatest number of inbound associations that can be\n           simultaneously open with this server.  If there is no limit,\n           then the value should be zero.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsSrvParamTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 7), )
if mibBuilder.loadTexts: rdbmsSrvParamTable.setDescription('The table of configuration parameters for a server.  Entries\n           should be populated according to the following guidelines:\n           (1) The value should be specified through administrative\n               (human) intervention.\n           (2) It should be configured on a per-server or a more global\n               basis, with duplicate entries for each server sharing\n               use of the parameter.\n           (3) One of the following is true:\n               (a) The parameter has a non-numeric value;\n               (b) The current value is numeric, but it only changes due\n                   to human intervention;\n\n               (c) The current value is numeric and dynamic, but the\n                   RDBMS does not track access/allocation failures\n                   related to the parameter;\n               (d) The current value is numeric and dynamic, the\n                   RDBMS tracks changes in access/allocation failures\n                   related to the parameter, but the failure has no\n                   significant impact on RDBMS performance or\n                   availability.\n               (e) The current value is numeric and dynamic, the\n                   RDBMS tracks changes in access/allocation failures\n                   related to the parameter, the failure has\n                   significant impact on RDBMS performance or\n                   availability, and is shown in the\n                   rdbmsSrvLimitedResource table.')
rdbmsSrvParamEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 7, 1), ).setIndexNames((0, "RDBMS-MIB", "applIndex"), (0, "RDBMS-MIB", "rdbmsSrvParamName"), (0, "RDBMS-MIB", "rdbmsSrvParamSubIndex"))
if mibBuilder.loadTexts: rdbmsSrvParamEntry.setDescription('An entry for a single configuration parameter for a server.\n           Parameters with single values have a subindex value of one.\n           If the parameter is naturally considered to contain a\n           variable number of members of a class, e.g.  members of the\n           DBA user group, or tracepoints active in the server, then it\n           must be presented as a set of rows.  If, on the other hand,\n           the parameter represents a set of choices from a class,\n           e.g. the permissions on a file or the options chosen out of\n           the set of all options allowed, AND is guaranteed to always\n           fit in the 255 character length of a DisplayString, then it\n           may be presented as a comma separated list with a subindex\n           value of one.  Zero may not be used as a subindex value.\n\n           Entries for a server must be present if the value of the\n           corresponding applOperStatus object is up(1).  If an instance\n           of applOperStatus is not up(1), then attempts to access\n           corresponding instances in this table may result in either\n           noSuchName (SNMPv1) or noSuchInstance (SNMPv2) being returned\n           by the agent.')
rdbmsSrvParamName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 7, 1, 1), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(1,64)))
if mibBuilder.loadTexts: rdbmsSrvParamName.setDescription('The name of a configuration parameter for a server.  This\n           name is product-specific. The length is limited to 64\n           characters to constrain the number of sub-identifiers needed\n           for instance identification (and to minimize network\n           traffic).')
rdbmsSrvParamSubIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 7, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: rdbmsSrvParamSubIndex.setDescription('The subindex value for this parameter.  If the parameter is\n           naturally considered to contain a variable number of members\n           of a class, e.g.  members of the DBA user group, or files\n           which are part of the database, then it must be presented as\n           a set of rows.  If, on the other hand, the parameter\n           represents a set of choices from a class, e.g. the\n           permissions on a file or the options chosen out of the set of\n           all options allowed, AND is guaranteed to always fit in the\n           255 character length of a DisplayString, then it may be\n           presented as a comma separated list with a subindex value of\n           one.  Zero may not be used as a value.')
rdbmsSrvParamID = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 7, 1, 3), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvParamID.setDescription('The ID of the parameter which may be described in some\n           other MIB.  If there is no ID for this rdbmsSrvParamName,\n           attempts to access this object will return noSuchName\n           (SNMPv1) or noSuchInstance (SNMPv2).')
rdbmsSrvParamCurrValue = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 7, 1, 4), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsSrvParamCurrValue.setDescription('The value for a configuration parameter now in effect, the\n           actual setting for the server.  While there may multiple\n           values in the temporal domain of interest (for instance, the\n           value to take effect at the next restart), this is the\n           current setting.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsSrvParamComment = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 7, 1, 5), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsSrvParamComment.setDescription("Annotation which describes the purpose of a configuration\n           parameter or the reason for a particular parameter's\n           setting.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.")
rdbmsSrvLimitedResourceTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 8), )
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceTable.setDescription('The table of limited resources relevant to a server.')
rdbmsSrvLimitedResourceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 8, 1), ).setIndexNames((0, "RDBMS-MIB", "applIndex"), (0, "RDBMS-MIB", "rdbmsSrvLimitedResourceName"))
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceEntry.setDescription('An entry for a single limited resource kept by the server.\n           A limited resource has maximum use determined by a parameter\n           that might or might not changeable at run time, or visible in\n           the rbmsSrvParamTable.  Examples would be the number of\n           available locks, or number of concurrent executions allowed\n           in a server.  Arrays of resources are supported through an\n           integer subindex, which should have the value of one for\n           single-instance names.\n\n           Limited resources that are shared across servers or databases\n           are best duplicated in this table across\n           all servers accessing the resource.')
rdbmsSrvLimitedResourceName = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 8, 1, 1), DisplayString())
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceName.setDescription("The name of the resource, for instance 'threads' or\n           'semaphores', or 'buffer pages'")
rdbmsSrvLimitedResourceID = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 8, 1, 2), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceID.setDescription('The ID of the resource which may be described in some other\n           MIB.  If there is no ID for this rdbmsSrvLimitedResourceName,\n           attempts to access this object will return noSuchName\n           (SNMPv1) or noSuchInstance (SNMPv2).')
rdbmsSrvLimitedResourceLimit = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 8, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceLimit.setDescription('The maximum value the resource use may attain.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsSrvLimitedResourceCurrent = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 8, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceCurrent.setDescription('The current value for the resource.')
rdbmsSrvLimitedResourceHighwater = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 8, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceHighwater.setDescription('The maximum value of the resource seen since applUpTime\n           was reset.')
rdbmsSrvLimitedResourceFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 8, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceFailures.setDescription('The number of times the system wanted to exceed the limit of\n           the resource since applUpTime was reset.')
rdbmsSrvLimitedResourceDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 8, 1, 7), DisplayString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rdbmsSrvLimitedResourceDescription.setDescription('A description of the resource and the meaning of the integer\n           units used for Limit, Current, and Highwater.\n\n           Note that a compliant agent does not need to\n           allow write access to this object.')
rdbmsRelTable = MibTable((1, 3, 6, 1, 2, 1, 39, 1, 9), )
if mibBuilder.loadTexts: rdbmsRelTable.setDescription('A table relating databases and servers present on a host.')
rdbmsRelEntry = MibTableRow((1, 3, 6, 1, 2, 1, 39, 1, 9, 1), ).setIndexNames((0, "RDBMS-MIB", "rdbmsDbIndex"), (0, "RDBMS-MIB", "applIndex"))
if mibBuilder.loadTexts: rdbmsRelEntry.setDescription("An entry relating a single database server to a single\n           database to which it may provide access.  The table is\n           indexed first by the index of rdbmsDbTable, and then\n           rdbmsSrvTable, so that all servers capable of providing\n           access to a given database may be found by SNMP traversal\n           operations (get-next and get-bulk).  The makeup of this table\n           depends on the product's architecture, e.g. if it is one\n           server - many databases, then each server will appear n\n           times, where n is the number of databases it may access, and\n           each database will appear once.  If the architecture is one\n           database - many servers, then each server will appear once\n           and each database will appear n times, where n is the number\n           of servers that may be accessing it.")
rdbmsRelState = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 9, 1, 1), Integer32().subtype(subtypeSpec=SingleValueConstraint(1, 2, 3, 4, 5,)).clone(namedValues=NamedValues(("other", 1), ("active", 2), ("available", 3), ("restricted", 4), ("unavailable", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsRelState.setDescription("The state of this server's access to this database.\n           Active(2) means the server is actively using the database.\n           Available(3) means the server could use the database if\n           necessary.  Restricted(4) means the database is in some\n           administratively determined state of less-than-complete\n           availability.  Unavailable(5) means the database is not\n           available through this server.  Other(1) means the\n           database/server is in some other condition, possibly\n           described in the vendor private MIB.")
rdbmsRelActiveTime = MibTableColumn((1, 3, 6, 1, 2, 1, 39, 1, 9, 1, 2), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rdbmsRelActiveTime.setDescription('The time the database was made active by the server.  If an\n           instance of rdbmsRelState is not active(1), then attempts to\n           access the corresponding instance of this object may result\n           in either noSuchName (SNMPv1) or noSuchInstance (SNMPv2)\n           being returned by the agent.')
rdbmsWellKnownLimitedResources = MibIdentifier((1, 3, 6, 1, 2, 1, 39, 1, 10))
rdbmsLogSpace = ObjectIdentity((1, 3, 6, 1, 2, 1, 39, 1, 10, 1))
if mibBuilder.loadTexts: rdbmsLogSpace.setDescription('Storage allocated for redo and undo logs.')
rdbmsTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 39, 2))
rdbmsStateChange = NotificationType((1, 3, 6, 1, 2, 1, 39, 2, 1)).setObjects(*(("RDBMS-MIB", "rdbmsRelState"),))
if mibBuilder.loadTexts: rdbmsStateChange.setDescription('An rdbmsStateChange trap signifies that one of the database\n           server/databases managed by this agent has changed its\n           rdbmsRelState in a way that makes it less accessible for use.\n           For these purposes, both active(2) and available(3) are\n           considered fully accessible.  The state sent with the trap is\n           the new, less accessible state.')
rdbmsOutOfSpace = NotificationType((1, 3, 6, 1, 2, 1, 39, 2, 2)).setObjects(*(("RDBMS-MIB", "rdbmsSrvInfoDiskOutOfSpaces"),))
if mibBuilder.loadTexts: rdbmsOutOfSpace.setDescription('An rdbmsOutOfSpace trap signifies that one of the database\n           servers managed by this agent has been unable to allocate\n           space for one of the databases managed by this agent.  Care\n           should be taken to avoid flooding the network with these\n           traps.')
rdbmsConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 39, 3))
rdbmsCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 39, 3, 1))
rdbmsGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 39, 3, 2))
rdbmsCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 39, 3, 1, 1)).setObjects(*(("HOST-RESOURCES-MIB", "hrSystem"), ("APPLICATION-MIB", "applGroup"), ("RDBMS-MIB", "rdbmsGroup"), ("RDBMS-MIB", "rdbmsGroup"),))
if mibBuilder.loadTexts: rdbmsCompliance.setDescription('The compliance statement for SNMP entities which\n           implement the RDBMS MIB')
rdbmsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 39, 3, 2, 1)).setObjects(*(("RDBMS-MIB", "rdbmsDbPrivateMibOID"), ("RDBMS-MIB", "rdbmsDbVendorName"), ("RDBMS-MIB", "rdbmsDbName"), ("RDBMS-MIB", "rdbmsDbContact"), ("RDBMS-MIB", "rdbmsDbInfoProductName"), ("RDBMS-MIB", "rdbmsDbInfoVersion"), ("RDBMS-MIB", "rdbmsDbInfoSizeUnits"), ("RDBMS-MIB", "rdbmsDbInfoSizeAllocated"), ("RDBMS-MIB", "rdbmsDbInfoSizeUsed"), ("RDBMS-MIB", "rdbmsDbInfoLastBackup"), ("RDBMS-MIB", "rdbmsDbParamCurrValue"), ("RDBMS-MIB", "rdbmsDbParamComment"), ("RDBMS-MIB", "rdbmsDbLimitedResourceLimit"), ("RDBMS-MIB", "rdbmsDbLimitedResourceCurrent"), ("RDBMS-MIB", "rdbmsDbLimitedResourceHighwater"), ("RDBMS-MIB", "rdbmsDbLimitedResourceFailures"), ("RDBMS-MIB", "rdbmsDbLimitedResourceDescription"), ("RDBMS-MIB", "rdbmsSrvPrivateMibOID"), ("RDBMS-MIB", "rdbmsSrvVendorName"), ("RDBMS-MIB", "rdbmsSrvProductName"), ("RDBMS-MIB", "rdbmsSrvContact"), ("RDBMS-MIB", "rdbmsSrvInfoStartupTime"), ("RDBMS-MIB", "rdbmsSrvInfoFinishedTransactions"), ("RDBMS-MIB", "rdbmsSrvInfoDiskReads"), ("RDBMS-MIB", "rdbmsSrvInfoDiskWrites"), ("RDBMS-MIB", "rdbmsSrvInfoLogicalReads"), ("RDBMS-MIB", "rdbmsSrvInfoLogicalWrites"), ("RDBMS-MIB", "rdbmsSrvInfoPageReads"), ("RDBMS-MIB", "rdbmsSrvInfoPageWrites"), ("RDBMS-MIB", "rdbmsSrvInfoHandledRequests"), ("RDBMS-MIB", "rdbmsSrvInfoRequestRecvs"), ("RDBMS-MIB", "rdbmsSrvInfoRequestSends"), ("RDBMS-MIB", "rdbmsSrvInfoHighwaterInboundAssociations"), ("RDBMS-MIB", "rdbmsSrvInfoMaxInboundAssociations"), ("RDBMS-MIB", "rdbmsSrvParamCurrValue"), ("RDBMS-MIB", "rdbmsSrvParamComment"), ("RDBMS-MIB", "rdbmsSrvLimitedResourceLimit"), ("RDBMS-MIB", "rdbmsSrvLimitedResourceCurrent"), ("RDBMS-MIB", "rdbmsSrvLimitedResourceHighwater"), ("RDBMS-MIB", "rdbmsSrvLimitedResourceFailures"), ("RDBMS-MIB", "rdbmsSrvLimitedResourceDescription"), ("RDBMS-MIB", "rdbmsRelState"), ("RDBMS-MIB", "rdbmsRelActiveTime"),))
if mibBuilder.loadTexts: rdbmsGroup.setDescription('A collection of objects providing basic instrumentation of an\n           RDBMS entity.')
mibBuilder.exportSymbols("RDBMS-MIB", rdbmsDbLimitedResourceFailures=rdbmsDbLimitedResourceFailures, rdbmsDbParamID=rdbmsDbParamID, rdbmsSrvParamSubIndex=rdbmsSrvParamSubIndex, rdbmsSrvVendorName=rdbmsSrvVendorName, rdbmsOutOfSpace=rdbmsOutOfSpace, rdbmsDbLimitedResourceDescription=rdbmsDbLimitedResourceDescription, rdbmsDbParamSubIndex=rdbmsDbParamSubIndex, rdbmsTraps=rdbmsTraps, rdbmsDbInfoVersion=rdbmsDbInfoVersion, rdbmsDbPrivateMibOID=rdbmsDbPrivateMibOID, rdbmsDbInfoProductName=rdbmsDbInfoProductName, rdbmsDbParamComment=rdbmsDbParamComment, rdbmsConformance=rdbmsConformance, rdbmsLogSpace=rdbmsLogSpace, rdbmsCompliance=rdbmsCompliance, rdbmsDbParamTable=rdbmsDbParamTable, rdbmsSrvInfoRequestSends=rdbmsSrvInfoRequestSends, rdbmsDbIndex=rdbmsDbIndex, rdbmsDbLimitedResourceName=rdbmsDbLimitedResourceName, rdbmsDbParamEntry=rdbmsDbParamEntry, rdbmsDbLimitedResourceID=rdbmsDbLimitedResourceID, rdbmsSrvParamName=rdbmsSrvParamName, rdbmsSrvLimitedResourceLimit=rdbmsSrvLimitedResourceLimit, rdbmsGroup=rdbmsGroup, rdbmsSrvProductName=rdbmsSrvProductName, rdbmsSrvInfoStartupTime=rdbmsSrvInfoStartupTime, rdbmsMIB=rdbmsMIB, rdbmsObjects=rdbmsObjects, rdbmsSrvInfoTable=rdbmsSrvInfoTable, rdbmsSrvTable=rdbmsSrvTable, rdbmsSrvLimitedResourceEntry=rdbmsSrvLimitedResourceEntry, rdbmsDbVendorName=rdbmsDbVendorName, rdbmsSrvLimitedResourceHighwater=rdbmsSrvLimitedResourceHighwater, rdbmsSrvInfoDiskReads=rdbmsSrvInfoDiskReads, rdbmsDbInfoSizeAllocated=rdbmsDbInfoSizeAllocated, rdbmsDbLimitedResourceCurrent=rdbmsDbLimitedResourceCurrent, rdbmsDbInfoSizeUsed=rdbmsDbInfoSizeUsed, rdbmsGroups=rdbmsGroups, rdbmsDbInfoSizeUnits=rdbmsDbInfoSizeUnits, rdbmsDbInfoLastBackup=rdbmsDbInfoLastBackup, rdbmsSrvLimitedResourceTable=rdbmsSrvLimitedResourceTable, rdbmsDbTable=rdbmsDbTable, rdbmsDbEntry=rdbmsDbEntry, rdbmsSrvContact=rdbmsSrvContact, rdbmsSrvParamCurrValue=rdbmsSrvParamCurrValue, rdbmsDbInfoTable=rdbmsDbInfoTable, rdbmsSrvLimitedResourceFailures=rdbmsSrvLimitedResourceFailures, PYSNMP_MODULE_ID=rdbmsMIB, rdbmsDbContact=rdbmsDbContact, rdbmsSrvInfoPageWrites=rdbmsSrvInfoPageWrites, rdbmsSrvInfoEntry=rdbmsSrvInfoEntry, rdbmsDbParamCurrValue=rdbmsDbParamCurrValue, rdbmsSrvParamTable=rdbmsSrvParamTable, rdbmsSrvInfoHandledRequests=rdbmsSrvInfoHandledRequests, rdbmsSrvLimitedResourceID=rdbmsSrvLimitedResourceID, rdbmsSrvInfoLogicalReads=rdbmsSrvInfoLogicalReads, rdbmsWellKnownLimitedResources=rdbmsWellKnownLimitedResources, rdbmsSrvInfoHighwaterInboundAssociations=rdbmsSrvInfoHighwaterInboundAssociations, rdbmsSrvParamID=rdbmsSrvParamID, rdbmsSrvInfoFinishedTransactions=rdbmsSrvInfoFinishedTransactions, rdbmsDbLimitedResourceEntry=rdbmsDbLimitedResourceEntry, rdbmsDbName=rdbmsDbName, rdbmsRelActiveTime=rdbmsRelActiveTime, rdbmsSrvInfoMaxInboundAssociations=rdbmsSrvInfoMaxInboundAssociations, rdbmsSrvParamEntry=rdbmsSrvParamEntry, rdbmsDbLimitedResourceHighwater=rdbmsDbLimitedResourceHighwater, rdbmsSrvInfoDiskOutOfSpaces=rdbmsSrvInfoDiskOutOfSpaces, rdbmsSrvPrivateMibOID=rdbmsSrvPrivateMibOID, rdbmsSrvParamComment=rdbmsSrvParamComment, rdbmsDbParamName=rdbmsDbParamName, rdbmsSrvLimitedResourceName=rdbmsSrvLimitedResourceName, rdbmsSrvInfoPageReads=rdbmsSrvInfoPageReads, rdbmsSrvInfoRequestRecvs=rdbmsSrvInfoRequestRecvs, rdbmsDbLimitedResourceLimit=rdbmsDbLimitedResourceLimit, rdbmsCompliances=rdbmsCompliances, rdbmsSrvInfoLogicalWrites=rdbmsSrvInfoLogicalWrites, rdbmsDbInfoEntry=rdbmsDbInfoEntry, rdbmsSrvLimitedResourceCurrent=rdbmsSrvLimitedResourceCurrent, rdbmsDbLimitedResourceTable=rdbmsDbLimitedResourceTable, rdbmsSrvInfoDiskWrites=rdbmsSrvInfoDiskWrites, rdbmsRelEntry=rdbmsRelEntry, rdbmsStateChange=rdbmsStateChange, rdbmsSrvEntry=rdbmsSrvEntry, rdbmsRelState=rdbmsRelState, rdbmsSrvLimitedResourceDescription=rdbmsSrvLimitedResourceDescription, rdbmsRelTable=rdbmsRelTable)



#
# PySNMP MIB module PARALLEL-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/PARALLEL-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:23:18 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsIntersection, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsIntersection", "ConstraintsUnion", "ValueRangeConstraint")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( Counter32, Gauge32, NotificationType, TimeTicks, ObjectIdentity, ModuleIdentity, transmission, Integer32, Counter64, IpAddress, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, MibIdentifier, iso, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "Gauge32", "NotificationType", "TimeTicks", "ObjectIdentity", "ModuleIdentity", "transmission", "Integer32", "Counter64", "IpAddress", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "MibIdentifier", "iso")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
para = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 34))
if mibBuilder.loadTexts: para.setLastUpdated('9405261700Z')
if mibBuilder.loadTexts: para.setOrganization('IETF Character MIB Working Group')
if mibBuilder.loadTexts: para.setContactInfo('        Bob Stewart\n                Postal: Xyplex, Inc.\n                        295 Foster Street\n                        Littleton, MA 01460\n\n                   Tel: 508-952-4816\n                   Fax: 508-952-4887\n                E-mail: rlstewart@eng.xyplex.com')
if mibBuilder.loadTexts: para.setDescription('The MIB module for Parallel-printer-like hardware devices.')
paraNumber = MibScalar((1, 3, 6, 1, 2, 1, 10, 34, 1), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraNumber.setDescription('The number of ports (regardless of their current\n           state) in the Parallel-printer-like port table.')
paraPortTable = MibTable((1, 3, 6, 1, 2, 1, 10, 34, 2), )
if mibBuilder.loadTexts: paraPortTable.setDescription('A list of port entries.  The number of entries is\n           given by the value of paraNumber.')
paraPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 34, 2, 1), ).setIndexNames((0, "PARALLEL-MIB", "paraPortIndex"))
if mibBuilder.loadTexts: paraPortEntry.setDescription('Status and parameter values for a port.')
paraPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 2, 1, 1), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraPortIndex.setDescription('The value of ifIndex for the port.  By convention\n           and if possible, hardware port numbers map directly\n           to external connectors.  The value for each port must\n           remain constant at least from one re-initialization\n           of the network management agent to the next.')
paraPortType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 2, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("other", 1), ("centronics", 2), ("dataproducts", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraPortType.setDescription("The port's hardware type.")
paraPortInSigNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 2, 1, 3), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraPortInSigNumber.setDescription('The number of input signals for the port in the\n           input signal table (paraPortInSigTable).  The table\n           contains entries only for those signals the software\n           can detect and that are useful to observe.')
paraPortOutSigNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 2, 1, 4), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraPortOutSigNumber.setDescription('The number of output signals for the port in the\n           output signal table (paraPortOutSigTable).  The\n           table contains entries only for those signals the\n           software can assert and that are useful to observe.')
paraInSigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 34, 3), )
if mibBuilder.loadTexts: paraInSigTable.setDescription('A list of port input control signal entries.')
paraInSigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 34, 3, 1), ).setIndexNames((0, "PARALLEL-MIB", "paraInSigPortIndex"), (0, "PARALLEL-MIB", "paraInSigName"))
if mibBuilder.loadTexts: paraInSigEntry.setDescription('Input control signal status for a hardware port.')
paraInSigPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 3, 1, 1), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraInSigPortIndex.setDescription('The value of paraPortIndex for the port to which\n           this entry belongs.')
paraInSigName = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 3, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("power", 1), ("online", 2), ("busy", 3), ("paperout", 4), ("fault", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraInSigName.setDescription('Identification of a hardware signal.')
paraInSigState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("none", 1), ("on", 2), ("off", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraInSigState.setDescription('The current signal state.')
paraInSigChanges = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 3, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraInSigChanges.setDescription("The number of times the signal has changed from\n           'on' to 'off' or from 'off' to 'on'.")
paraOutSigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 34, 4), )
if mibBuilder.loadTexts: paraOutSigTable.setDescription('A list of port output control signal entries.')
paraOutSigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 34, 4, 1), ).setIndexNames((0, "PARALLEL-MIB", "paraOutSigPortIndex"), (0, "PARALLEL-MIB", "paraOutSigName"))
if mibBuilder.loadTexts: paraOutSigEntry.setDescription('Output control signal status for a hardware port.')
paraOutSigPortIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 4, 1, 1), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraOutSigPortIndex.setDescription('The value of paraPortIndex for the port to which\n           this entry belongs.')
paraOutSigName = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 4, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("power", 1), ("online", 2), ("busy", 3), ("paperout", 4), ("fault", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraOutSigName.setDescription('Identification of a hardware signal.')
paraOutSigState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 4, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("none", 1), ("on", 2), ("off", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraOutSigState.setDescription('The current signal state.')
paraOutSigChanges = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 34, 4, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: paraOutSigChanges.setDescription("The number of times the signal has changed from\n           'on' to 'off' or from 'off' to 'on'.")
paraConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 34, 5))
paraGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 34, 5, 1))
paraCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 34, 5, 2))
paraCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 34, 5, 2, 1)).setObjects(*(("PARALLEL-MIB", "paraGroup"),))
if mibBuilder.loadTexts: paraCompliance.setDescription('The compliance statement for SNMPv2 entities\n               which have Parallel-printer-like hardware\n               interfaces.')
paraGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 34, 5, 1, 1)).setObjects(*(("PARALLEL-MIB", "paraNumber"), ("PARALLEL-MIB", "paraPortIndex"), ("PARALLEL-MIB", "paraPortType"), ("PARALLEL-MIB", "paraPortInSigNumber"), ("PARALLEL-MIB", "paraPortOutSigNumber"), ("PARALLEL-MIB", "paraInSigPortIndex"), ("PARALLEL-MIB", "paraInSigName"), ("PARALLEL-MIB", "paraInSigState"), ("PARALLEL-MIB", "paraInSigChanges"), ("PARALLEL-MIB", "paraOutSigPortIndex"), ("PARALLEL-MIB", "paraOutSigName"), ("PARALLEL-MIB", "paraOutSigState"), ("PARALLEL-MIB", "paraOutSigChanges"),))
if mibBuilder.loadTexts: paraGroup.setDescription('A collection of objects providing information\n                applicable to all Parallel-printer-like interfaces.')
mibBuilder.exportSymbols("PARALLEL-MIB", paraOutSigPortIndex=paraOutSigPortIndex, paraInSigState=paraInSigState, paraInSigName=paraInSigName, paraNumber=paraNumber, paraOutSigState=paraOutSigState, paraOutSigName=paraOutSigName, paraPortOutSigNumber=paraPortOutSigNumber, paraPortTable=paraPortTable, PYSNMP_MODULE_ID=para, paraGroup=paraGroup, paraInSigChanges=paraInSigChanges, paraPortInSigNumber=paraPortInSigNumber, paraPortEntry=paraPortEntry, paraInSigPortIndex=paraInSigPortIndex, paraOutSigChanges=paraOutSigChanges, paraInSigTable=paraInSigTable, para=para, paraOutSigTable=paraOutSigTable, paraPortType=paraPortType, paraGroups=paraGroups, paraOutSigEntry=paraOutSigEntry, paraConformance=paraConformance, paraPortIndex=paraPortIndex, paraCompliance=paraCompliance, paraCompliances=paraCompliances, paraInSigEntry=paraInSigEntry)
